#!/bin/bash

# Name: aufs2-util - Utilities for aufs2
# Summary: Another Union filesystem.
# Homepage: http://aufs.sourceforge.net/
# Maintainer: Pierric Le Brun (akuna at free.fr)
#

softname="aufs2-util"
softversion="20090327"
kernelversion="$(uname -r)"
arch="i486"
cpu="i686"

buildir=$(pwd)

srcpkg="$softname.tar.gz"
src="$buildir/$softname"
package="$softname-$softversion-$arch-$kernelversion"
dest="$buildir/$package"


cd $buildir
rm -rf $src
tar -xvf $srcpkg

cd $src

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
 
make

rm -f $dest.tgz
rm -rf $dest

mkdir -p $dest/sbin
cp {mount,umount}.aufs $dest/sbin
cp auplink $dest/sbin
cp auchk $dest/sbin

mkdir -p $dest/etc/default
cp etc_default_aufs $dest/etc/default/aufs

mkdir -p $dest/usr/doc/$softname-$softversion
cp COPYING README $dest/usr/doc/$softname-$softversion/


# Description file
mkdir -p $dest/install
cat << "EODESC" > $dest/install/slack-desc
aufs2-util: aufs2-util - aufs2 utilities
aufs2-util:
aufs2-util: aufs is a stackable unification filesystem such as Unionfs,
aufs2-util: which unifies several directories and provides a merged single
aufs2-util: directory.
aufs2-util:
aufs2-util: Once aufs was a entirely re-designed and re-implemented Unionfs
aufs2-util: Enhancing with many original ideas, it becomes a totally
aufs2-util: different software while keeping the basic features.
aufs2-util:
aufs2-util:
EODESC

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
mkdir -p $dest/usr/src/$softname-$softversion
(
  cd $buildir
  cp -a build-$softname.sh $dest/usr/src/$softname-$softversion/
)

# set target permissions
chown -R root:root $dest

cd $dest
makepkg -l y -c n $dest.tgz

cd $builddir
md5sum $dest.tgz > $dest.md5
requiredbuilder -z $dest.tgz > $dest.dep
echo kernelive >> $dest.dep
